==> hdf5-1.12.3-1-src.tar.xz: hdf5-1.12.3/doxygen/examples/menus/core_menu.md <==
<b>Core Library</b>

- @ref H5A "Attributes (H5A)"
<br />
HDF5 attribute is a small metadata object describing the nature and/or intended usage of a primary data object.

- @ref H5D "Datasets (H5D)"
<br />
Manage HDF5 datasets, including the transfer of data between memory and disk and the description of dataset properties.

- @ref H5S "Dataspaces (H5S)"
<br />
HDF5 dataspaces describe the shape of datasets in memory or in HDF5 files.

- @ref H5T "Datatypes (H5T)"
<br />
HDF5 datatypes describe the element type of HDF5 datasets and attributes.

- @ref H5E "Error Handling (H5E)"
<br />
HDF5 library error reporting.

- @ref H5F "Files (H5F)"
<br />
Manage HDF5 files.

- @ref H5Z "Filters (H5Z)"
<br />
Manage HDF5 user-defined filters

- @ref H5G "Groups (H5G)"
<br />
Manage HDF5 groups.

- @ref H5I "Identifiers (H5I)"
<br />
Manage identifiers defined by the HDF5 library.

- @ref H5 "Library General (H5)"
<br />
Manage the life cycle of HDF5 library instances.

- @ref H5L "Links (H5L)"
<br />
Manage HDF5 links and link types.

- @ref H5O "Objects (H5O)"
<br />
Manage HDF5 objects (groups, datasets, datatype objects).

- @ref H5P "Property Lists (H5P)"
<br />
HDF5 property lists are the main vehicle to configure the behavior of HDF5 API functions.

- @ref H5PL "Dynamically-loaded Plugins (H5PL)"
<br />
Manage the loading behavior of HDF5 plugins.

- @ref H5R "References (H5R)"
<br />
Manage HDF5 references (HDF5 objects, attributes, and selections on datasets a.k.a. dataset regions).

- @ref H5VL "VOL Connector (H5VL)"
<br />
Manage HDF5 VOL connector plugins.

==> hdf5-2.0.0-1-src.tar.xz: hdf5-2.0.0/doxygen/examples/menus/core_menu.md <==
<b>Core Library</b>

- @ref H5A "Attributes (H5A)"
<br />
HDF5 attribute is a small metadata object describing the nature and/or intended usage of a primary data object.

- @ref H5D "Datasets (H5D)"
<br />
Manage HDF5 datasets, including the transfer of data between memory and disk and the description of dataset properties.

- @ref H5S "Dataspaces (H5S)"
<br />
HDF5 dataspaces describe the shape of datasets in memory or in HDF5 files.

- @ref H5T "Datatypes (H5T)"
<br />
HDF5 datatypes describe the element type of HDF5 datasets and attributes.

- @ref H5E "Error Handling (H5E)"
<br />
HDF5 library error reporting.

- @ref H5ES "Event Set (H5ES)"
<br />
HDF5 event set life cycle used with HDF5 VOL connectors that enable the asynchronous feature in HDF5.

- @ref H5F "Files (H5F)"
<br />
Manage HDF5 files.

- @ref H5Z "Filters (H5Z)"
<br />
Manage HDF5 user-defined filters

- @ref H5G "Groups (H5G)"
<br />
Manage HDF5 groups.

- @ref H5I "Identifiers (H5I)"
<br />
Manage identifiers defined by the HDF5 library.

- @ref H5 "Library General (H5)"
<br />
Manage the life cycle of HDF5 library instances.

- @ref H5L "Links (H5L)"
<br />
Manage HDF5 links and link types.

- @ref H5O "Objects (H5O)"
<br />
Manage HDF5 objects (groups, datasets, datatype objects).

- @ref H5P "Property Lists (H5P)"
<br />
HDF5 property lists are the main vehicle to configure the behavior of HDF5 API functions.

- @ref H5PL "Dynamically-loaded Plugins (H5PL)"
<br />
Manage the loading behavior of HDF5 plugins.

- @ref H5R "References (H5R)"
<br />
Manage HDF5 references (HDF5 objects, attributes, and selections on datasets a.k.a. dataset regions).

- @ref H5VL "VOL Connector (H5VL)"
<br />
Manage HDF5 VOL connector plugins.
